#
# spec file for package python-apprise
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2024 Paolo Panto <munix9@googlemail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1

%if 0%{?suse_version} > 1500
%bcond_without libalternatives
%else
%bcond_with    libalternatives
%endif

Name:           python-apprise
Version:        1.9.0
Release:        1.1
Group:          Development/Libraries/Python
Summary:        A simple wrapper to many popular notification services used today
License:        BSD-2-Clause
URL:            https://github.com/caronc/apprise
Source0:        https://files.pythonhosted.org/packages/source/a/apprise/apprise-%{version}.tar.gz
Source99:       %{name}.rpmlintrc
%if 0%{?suse_version} <= 1500
BuildRequires:  %{python_module dataclasses}
Requires:       python-dataclasses
%endif
BuildRequires:  %{python_module Babel}
BuildRequires:  %{python_module Markdown}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module certifi}
BuildRequires:  %{python_module click >= 5.0}
BuildRequires:  %{python_module dbus-python}
BuildRequires:  %{python_module paho-mqtt}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests-oauthlib}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
Requires:       python-Markdown
Requires:       python-PyYAML
Requires:       python-certifi
Requires:       python-click >= 5.0
Requires:       python-requests
Requires:       python-requests-oauthlib
Recommends:     python-paho-mqtt
Suggests:       python-dbus-python
%if %{with libalternatives}
BuildRequires:  alts
Requires:       alts
%else
Requires(post): update-alternatives
Requires(postun): update-alternatives
%endif
BuildArch:      noarch
%python_subpackages

%description
Apprise is a Python package for simplifying access to all of the different
notification services that are out there. Apprise opens the door and makes
it easy to access:

Apprise API, APRS, AWS SES, AWS SNS, Bark, Boxcar, Burst SMS, BulkSMS, BulkVS,
ClickSend, DAPNET, DingTalk, Discord, E-Mail, Emby, Faast, FCM, Flock,
Google Chat, Gotify, Growl, Guilded, Home Assistant, httpSMS, IFTTT, Join,
Kavenegar, KODI, Kumulos, LaMetric, Line, MacOSX, Mailgun, Mastodon,
Mattermost,Matrix, MessageBird, Microsoft Windows, Microsoft Teams, Misskey,
MQTT, MSG91, MyAndroid, Nexmo, Nextcloud, NextcloudTalk, Notica, Notifiarr,
Notifico, ntfy, Office365, OneSignal, Opsgenie, PagerDuty, PagerTree,
ParsePlatform, PopcornNotify, Prowl, Pushalot, PushBullet, Pushjet, PushMe,
Pushover, PushSafer, Pushy, PushDeer, Reddit, Rocket.Chat, RSyslog, SendGrid,
ServerChan, Signal, SimplePush, Sinch, Slack, SMSEagle, SMS Manager, SMTP2Go,
SparkPost, Super Toasty, Streamlabs, Stride, Synology Chat, Syslog,
Techulus Push, Telegram, Threema Gateway, Twilio, Twitter, Twist, XBMC,
Voipms, Vonage, WeCom Bot, WhatsApp, Webex Teams.

%prep
%autosetup -n apprise-%{version} -p1

%build
%pyproject_wheel

%install
%pyproject_install
install -D -m 0644 -t %{buildroot}%{_mandir}/man1 packaging/man/apprise.1

%python_clone -a %{buildroot}%{_bindir}/apprise
%python_clone -a %{buildroot}%{_mandir}/man1/apprise.1
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -k 'not test_plugin_matrix_attachments_api_v2 and not test_apprise_attachment_truncate and not test_plugin_dbus'

%pre
%python_libalternatives_reset_alternative apprise

%post
%python_install_alternative apprise apprise.1%{?ext_man}

%postun
%python_uninstall_alternative apprise

%files %{python_files}
%license LICENSE
%doc README.md
%python_alternative %{_bindir}/apprise
%python_alternative %{_mandir}/man1/apprise.1%{?ext_man}
%{python_sitelib}/apprise
%{python_sitelib}/apprise-%{version}.dist-info

%changelog
* Mon Sep  9 2024 Joshua Smith <smolsheep@opensuse.org>
- Remove fix-test_plugin_glib.patch -- Fixed upstream
- Update to version 1.9.0:
  Features:
  * Added WxPusher Support
  * Persistent Storage added. This feature is very big and better documented here.
    https://github.com/caronc/apprise/wiki/persistent_storage
    Long overdue, plugins can now safely cache some of the query
    results returned from upstream endpoints to disk. This saves
    the need to make future extra web requests later (overall
    causing a performance boost to Apprise). It's a cache engine
    done right; content is contained, and those using the CLI can
    clean/reset it. You can also easily turn it off.
  * mqtt:// support for publishing retain flag
  * SendGrid Attachment Support Added
  * Refactored base64 attachment handling
  Fixes:
  * Fix typo in readme
  * Fix Telegram Thread/Topic handling
  * Fixed mattermost channel handling
  * Escape unsupported Telegram MarkdownV2 characters
    Telegram MarkdownV2 has turned out to be a VERY different style
    of markdown. For consistency, the default telegram mode is
    version 1. Simply add ?format=markdown&mdv=v2 to your URL to
    change this.
* Fri Jul 26 2024 Joshua Smith <smolsheep@opensuse.org>
- Remove apprise-pytest-session_mocker-removal.patch -- Fixed upstream
- Update to version 1.8.1:
  Features:
  * New Services:
  - Splunk
  - Africas Talking
  - Microsoft Power Automate / Workflows
  - Société Française du Radiotéléphone (SFR)
  * Slack supports <@userid> in message body
  * Turn large ntfy messages into a attachments
  * Refactored the way Notifiarr Discord users are mentioned
  * OneSignal to support custom data in payload
  * Twilio WhatsApp support added
  * Allow json data in OneSignal template arguments
  Fixes:
  * Automatically increment Matrix v3 transaction IDs
  * Slack files upload deprecation
  * Update token regex in ServerChan
  * Add missing %% string in import failed trace message
  * This will fix issues with Home Assistant
  * Fixes random matrix:// unittest failures
  * fix: conversion html_to_text hr tags rstrip non string object
- Updates from version 1.8.0:
  Features:
  * Custom Plugin Attachment Support Enforced + Added Testing
  * Do not sanitize http:// attachment URLs. This allows the
    successful fetching of very complicated http based Attachment
    URL's where the case sensitivity of the keys matter. The side
    effect of this change, is built in switches like cache= become
    case sensitive too (e.g Cache= will no longer be parsed).
  Fixes:
  * Added JSON Content-Type header to freemobile://
  * Fix mailto://ip.addr support
  * clicksend:// authentication bugfix
  * Update Apprise API (apprise//) token length
* Tue Apr 23 2024 Joshua Smith <smolsheep@opensuse.org>
- Disable another failing test
* Mon Apr 15 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to version 1.7.6:
  Features:
  * Chantify Support added
  * Feishu Custom Bot Support added
  * Added delay= switch to aprs:// plugin
  * RocketChat Token Support
  Bugfixes:
  * Default locale logical compatibility with Python 3.12
  * Fixed deprication warnings for Markdown extensions
  * ntfy loaded topic count bugfix
  * freemobile:// msg moved from GET parameters and into payload
  * Honor overflow=truncate when sending attachments
  * host parsed from user login (if present) for Emails
* Wed Apr  3 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to version 1.7.5:
  Features:
  * Free-Mobile support added
  * Improved markdown to html conversions
  * Added test case to strengthen YAML configuration validation
  Bugfixes:
  * Improved async/threading attachment support
  * Improved variable parsing in YAML files
* Sun Mar 10 2024 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 1.7.4:
  Features:
  * LunaSea support added
  * .conf configuration file support added to CLI.
  Fixes:
  * Fix: Custom module deadlock which fixes bug from 1.7.3
* Sun Mar  3 2024 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 1.7.3:
  Features:
  * Revolt support added
  * mailto comcast email template added
  * mailto *improved custom email server handling, to= and
    from_addr= are no longer required in most circumstances
  * ntfy markdown support added, just add ?format=markdown
  Fixes:
  * Fixed documents with respect to the use of yaml files
  * Asynchronous dynamic module loading support
* Thu Feb 15 2024 Joshua Smith <jsmithfpv@gmail.com>
- Added single-line patch comments to better conform to patch
  guidelines.
* Sun Jan 28 2024 Paolo Panto <munix9@googlemail.com>
- Initial package (version 1.7.2) for openSUSE
